@@ -457,8 +457,8 @@ sub new
 			my %globalArgs = (
 					'-noiframes' => 1, '-fast' => 1, '-debug' => $DEBUG
 			);
-			foreach my $arg (qw(secure log logfmt youtube-format youtube-formatonly
-					youtube-dl-args youtube-dl-add-args)) {
+			foreach my $arg (qw(secure log logfmt youtube-format youtube-format-fallback
+					youtube-formatonly youtube-dl-args youtube-dl-add-args)) {
 				(my $arg0 = $arg) =~ s/^youtube\-(?!dl)//o;
 				$globalArgs{$arg0} = $self->{$arg}  if (defined $self->{$arg});
 			}
